diff -rupN old/drivers/scsi/megaraid/megaraid_sas.c new/drivers/scsi/megaraid/megaraid_sas.c
--- old/drivers/scsi/megaraid/megaraid_sas.c	2010-11-14 15:40:53.000000000 -0500
+++ new/drivers/scsi/megaraid/megaraid_sas.c	2010-11-14 15:47:47.000000000 -0500
@@ -3146,6 +3146,15 @@ megasas_issue_init_mfi(struct megasas_in
 
 	init_frame->cmd = MFI_CMD_INIT;
 	init_frame->cmd_status = 0xFF;
+
+	if (instance->verbuf) {
+	snprintf((char *)instance->verbuf, strlen(MEGASAS_VERSION) + 2, "%s\n",
+			MEGASAS_VERSION);
+
+		init_frame->driver_ver_lo = instance->verbuf_h;
+		init_frame->driver_ver_hi = 0;
+	}
+
 	init_frame->queue_info_new_phys_addr_lo = initq_info_h;
 
 	init_frame->data_xfer_len = sizeof(struct megasas_init_queue_info);
@@ -3323,6 +3332,14 @@ static int megasas_init_mfi(struct megas
 		goto fail_reply_queue;
 	}
 
+	instance->verbuf = pci_alloc_consistent(instance->pdev,
+						MEGASAS_MAX_NAME*sizeof(u32),
+						&instance->verbuf_h);
+
+	if (!instance->verbuf) {
+		printk(KERN_DEBUG "megasas: Can't allocate version buffer\n");
+	}
+
 	if (megasas_issue_init_mfi(instance))
 		goto fail_fw_init;
 
@@ -4228,6 +4245,11 @@ static void __devexit megasas_detach_one
 	pci_free_consistent(pdev, sizeof(u32), instance->consumer,
 			    instance->consumer_h);
 
+	if (instance->verbuf) {
+		pci_free_consistent(pdev, MEGASAS_MAX_NAME*sizeof(u32),
+			instance->verbuf, instance->verbuf_h);
+	}
+
 	scsi_host_put(host);
 
 	pci_set_drvdata(pdev, NULL);
diff -rupN old/drivers/scsi/megaraid/megaraid_sas.h new/drivers/scsi/megaraid/megaraid_sas.h
--- old/drivers/scsi/megaraid/megaraid_sas.h	2010-11-11 05:46:19.000000000 -0500
+++ new/drivers/scsi/megaraid/megaraid_sas.h	2010-11-14 14:25:14.000000000 -0500
@@ -706,6 +706,7 @@ struct megasas_ctrl_info {
 #define MEGASAS_MAX_LD_IDS			(MEGASAS_MAX_LD_CHANNELS * \
 						MEGASAS_MAX_DEV_PER_CHANNEL)
 
+#define MEGASAS_MAX_NAME			32
 #define MEGASAS_MAX_SECTORS                    (2*1024)
 #define MEGASAS_DBG_LVL				1
 
@@ -887,7 +888,10 @@ struct megasas_init_frame {
 	u32 queue_info_old_phys_addr_lo;	/*20h */
 	u32 queue_info_old_phys_addr_hi;	/*24h */
 
-	u32 reserved_4[6];	/*28h */
+	u32 driver_ver_lo;
+	u32 driver_ver_hi;
+
+	u32 reserved_4[4];	/*28h */
 
 } __attribute__ ((packed));
 
@@ -1259,6 +1263,8 @@ struct megasas_instance {
 	dma_addr_t producer_h;
 	u32 *consumer;
 	dma_addr_t consumer_h;
+	u32 *verbuf;
+	dma_addr_t verbuf_h;
 
 	u32 *reply_queue;
 	dma_addr_t reply_queue_h;
